Computer Webmaster Gaming Console Graphics Forum

Welcome to the Computer Webmaster Gaming Console Graphics Forum forums.

You are currently viewing our boards as a guest which gives you limited access to view most discussions and access our other features. By joining our free community you will have access to post topics, communicate privately with other members (PM), respond to polls, upload content and access many other special features. Registration is fast, simple and absolutely free so please, join our community today!

If you have any problems with the registration process or your account login, please contact contact us.

MK PitStop Main Earn $25 Earn Money Posting Extras Members Blogs Image Hosting User Pages
Go Back   Computer Webmaster Gaming Console Graphics Forum > Webmaster Forum > Website Coding > Pear
Register FAQ/Rules Become A V.I.P. Member Search Today's Posts Mark Forums Read

Pear Pear programming, this is a very complex subject as with using pear with php can be a difficult task for some, so lets talk pear.

Google
Closed Thread
 
LinkBack Thread Tools Display Modes
Old 05-20-2007, 7:42 PM   #1
 
's Avatar
 
Posts: n/a
My Photos: (0)

Banked:
MK Cash: $

I am Worth:
MK Cash: $
Donate

Recent Blog: None

Default cvs: pear /PEAR_Frontend_Web pearfrontendweb.php /PEAR_Frontend_Web/Frontend Web.php

tias Sat May 19 16:02:18 2007 UTC

Modified files:
/pear/PEAR_Frontend_Web pearfrontendweb.php
/pear/PEAR_Frontend_Web/Frontend Web.php
Log:
list-files of package


http://cvs.php.net/viewvc.cgi/pear/P...&diff_format=u
Index: pear/PEAR_Frontend_Web/pearfrontendweb.php
diff -u pear/PEAR_Frontend_Web/pearfrontendweb.php:1.57 pear/PEAR_Frontend_Web/pearfrontendweb.php:1.58
--- pear/PEAR_Frontend_Web/pearfrontendweb.php:1.57 Sat May 19 15:36:39 2007
+++ pear/PEAR_Frontend_Web/pearfrontendweb.php Sat May 19 16:02:17 2007
@@ -29,7 +29,7 @@
* @author Tias Guns <tias@ulyssis.org>
* @copyright 1997-2007 The PHP Group
* @license http://www.php.net/license/2_02.txt PHP License 2.02
- * @version CVS: $Id: pearfrontendweb.php,v 1.57 2007/05/19 15:36:39 tias Exp $
+ * @version CVS: $Id: pearfrontendweb.php,v 1.58 2007/05/19 16:02:17 tias Exp $
* @link http://pear.php.net/package/PEAR_Frontend_Web
* @since File available since Release 0.1
*/
@@ -295,6 +295,11 @@

$ui->finishOutput('Back', array('link' => $_SERVER['PHP_SELF'].'?command='.$command, 'text' => 'Back to the config'));
break;
+ case 'list-files':
+ $params = array($_GET['pkg']);
+ $cmd = PEAR_Command::factory($command, $config);
+ $res = $cmd->run($command, $opts, $params);
+ break;
case 'list-docs':
if (!isset($_GET['pkg'])) {
PEAR::raiseError('The webfrontend-command list-docs needs at least one \'pkg\' argument.');
http://cvs.php.net/viewvc.cgi/pear/P...&diff_format=u
Index: pear/PEAR_Frontend_Web/Frontend/Web.php
diff -u pear/PEAR_Frontend_Web/Frontend/Web.php:1.73 pear/PEAR_Frontend_Web/Frontend/Web.php:1.74
--- pear/PEAR_Frontend_Web/Frontend/Web.php:1.73 Sat May 19 15:36:39 2007
+++ pear/PEAR_Frontend_Web/Frontend/Web.php Sat May 19 16:02:18 2007
@@ -23,7 +23,7 @@
* @author Tias Guns <tias@ulyssis.org>
* @copyright 1997-2007 The PHP Group
* @license http://www.php.net/license/2_02.txt PHP License 2.02
- * @version CVS: $Id: Web.php,v 1.73 2007/05/19 15:36:39 tias Exp $
+ * @version CVS: $Id: Web.php,v 1.74 2007/05/19 16:02:18 tias Exp $
* @link http://pear.php.net/package/PEAR_Frontend_Web
* @since File available since Release 0.1
*/
@@ -50,7 +50,7 @@
* @author Tias Guns <tias@ulyssis.org>
* @copyright 1997-2007 The PHP Group
* @license http://www.php.net/license/2_02.txt PHP License 2.02
- * @version CVS: $Id: Web.php,v 1.73 2007/05/19 15:36:39 tias Exp $
+ * @version CVS: $Id: Web.php,v 1.74 2007/05/19 16:02:18 tias Exp $
* @link http://pear.php.net/package/PEAR_Frontend_Web
* @since File available since Release 0.1
*/
@@ -406,12 +406,28 @@
}

// }}}
+ // {{{ _outputListFiles()
+
+ /**
+ * Output a list of files of a packagename
+ *
+ * @param array $data array containing all files of a package
+ *
+ * @return boolean true (yep. i am an optimist)
+ */
+ function _outputListFiles($data)
+ {
+ sort($data['data']);
+ return $this->_outputGenericTableVertical($data['caption'], $data['data']);
+ }
+
+ // }}}
// {{{ _outputListDocs()

/**
- * Output a list of documentation files of a packagenames
+ * Output a list of documentation files of a packagename
*
* @param array $data array containing all documentation files of a packages
*
* @return boolean true (yep. i am an optimist)
*/
@@ -950,6 +966,11 @@
$image);
$output .= '<br />';
}
+ $output .= sprintf(
+ '<a href="%s?command=list-files&pkg=%s" class="green">./.. List Files</a>',
+ $_SERVER["PHP_SELF"],
+ $package);
+ $output .= '<br />';
// More: Extended Package Information
$image = sprintf('<img src="%s?img=infoplus" border="0" alt="extra info">', $_SERVER["PHP_SELF"]);
if ($channel == 'pear.php.net' || $channel == 'pecl.php.net') {
@@ -1259,6 +1280,8 @@
$GLOBALS['_PEAR_Frontend_Web_Config'] =
$this->userDialog($command, $prompt, array(), $default, $title, 'config');
return true;
+ case 'list-files':
+ return $this->_outputListFiles($data);
case 'list-docs':
return $this->_outputListDocs($data);
case 'doc-show':
@@ -406,12 +406,28 @@
*
- * @param array $data array containing all documentation files of a packages
+ * @param array $data array containing all documentation files of a package
*
* @return boolean true (yep. i am an optimist)
 
Add Post to del.icio.usBookmark Post in TechnoratiFurl this Post!Spurl this Post!Reddit!
Featured Websites
Free Space
Free Space
Free Space Free Space
Closed Thread
Tags: , , , ,




Currently Active Users Viewing This Thread: 1 (0 members and 1 guests)
 
Thread Tools
Display Modes

Posting Rules
You may not post new threads
You may not post replies
You may not post attachments
You may not edit your posts

vB code is On
Smilies are On
[IMG] code is On
HTML code is Off
Trackbacks are On
Pingbacks are On
Refbacks are On

Similar Threads
Thread Thread Starter Forum Replies Last Post
cvs: pear /PEAR_Frontend_Web package.xml pearfrontendweb.php pearweb.php /PEAR_Frontend_Web/docs example.php index.php.txt Pear 0 05-20-2007 7:42 PM
cvs: pear /PEAR_Frontend_Web pearfrontendweb.php /PEAR_Frontend_Web/Frontend Web.php /PEAR_Frontend_Web/Frontend/Web Docviewer.php /PEAR_Frontend_Web/data style.css Pear 0 05-20-2007 7:42 PM
cvs: pear /PEAR_Frontend_Web/Frontend/Web/data package.js style.css /PEAR_Frontend_Web/Frontend/Web/data/images category.jpg config.gif download.gif error.gif info.gif infoplus.gif install.gif install_fail.gif install_ok.gif install_wait.gif login.g Pear 0 05-20-2007 7:42 PM
cvs: pear /PEAR_Frontend_Web package.xml pearweb.php /PEAR_Frontend_Web/Frontend Web.php /PEAR_Frontend_Web/docs example.php index.php.txt Pear 0 05-20-2007 7:42 PM
cvs: pear(1) /PEAR_Frontend_Web/Frontend Web_Command_Forward_Compatible.php /PEAR_Frontend_Web/Frontend/Web Command_Forward_Compatible.php Pear 0 05-20-2007 7:42 PM


Featured Websites




All times are GMT +1. The time now is 8:24 PM.


Powered by: vBulletin Copyright ©2000 - 2008, Jelsoft Enterprises Ltd.
LinkBacks Enabled by vBSEO 3.0.0
Cheap Computers
MK PitStop Copyright 2005 - 2008

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98